==> OAIHarvester_0.1-2.tar.gz: OAIHarvester/inst/doc/oaih.R <==
###################################################
### chunk number 1: 
###################################################
#line 194 "oaih.Rnw"
library("OAIHarvester")
baseurl <- "http://epub.wu.ac.at/cgi/oai2"


###################################################
### chunk number 2: 
###################################################
#line 200 "oaih.Rnw"
require("XML")
options(warnPartialMatchArgs = FALSE)
options(width = 80)


###################################################
### chunk number 3: 
###################################################
#line 208 "oaih.Rnw"
x <- oaih_identify(baseurl)
rbind(x, deparse.level = 0)


###################################################
### chunk number 4: 
###################################################
#line 216 "oaih.Rnw"
sapply(x$description, xmlName)


###################################################
### chunk number 5: 
###################################################
#line 221 "oaih.Rnw"
oaih_transform(x$description[[1L]])


###################################################
### chunk number 6: 
###################################################
#line 227 "oaih.Rnw"
oaih_list_metadata_formats(baseurl)
sets <- oaih_list_sets(baseurl)
rbind(head(sets, 3L), tail(sets, 3L))


###################################################
### chunk number 7: 
###################################################
#line 236 "oaih.Rnw"
spec <- unlist(sets[sets[, "setName"] == "Type = Thesis", "setSpec"])


###################################################
### chunk number 8: 
###################################################
#line 240 "oaih.Rnw"
x <- oaih_list_records(baseurl, set = spec)


###################################################
### chunk number 9: 
###################################################
#line 245 "oaih.Rnw"
dim(x)
colnames(x)


###################################################
### chunk number 10: 
###################################################
#line 252 "oaih.Rnw"
m <- x[, "metadata"]
m <- oaih_transform(m[sapply(m, length) > 0L])
dim(m)


###################################################
### chunk number 11: 
###################################################
#line 258 "oaih.Rnw"
colnames(m)


###################################################
### chunk number 12: 
###################################################
#line 311 "oaih.Rnw"
m[c(2L, 5L, 6L), "subject"]


###################################################
### chunk number 13: 
###################################################
#line 316 "oaih.Rnw"
sep <- "[[:space:]]*/[[:space:]]*"
keywords_by_thesis <- strsplit(unlist(m[, "subject"]), sep)
keywords <- unlist(keywords_by_thesis)


###################################################
### chunk number 14: 
###################################################
#line 323 "oaih.Rnw"
counts <- table(keywords)
table(counts)


###################################################
### chunk number 15: 
###################################################
#line 329 "oaih.Rnw"
sort(counts[counts >= 3L], decreasing = TRUE)


###################################################
### chunk number 16: 
###################################################
#line 334 "oaih.Rnw"
counts["R"]


###################################################
### chunk number 17: 
###################################################
#line 338 "oaih.Rnw"
m[sapply(keywords_by_thesis, function(kw) any(kw == "R")),
  c("title", "creator")]


###################################################
### chunk number 18: 
###################################################
#line 345 "oaih.Rnw"
m[grep("^Feinerer", unlist(m[, "creator"])),
  c("title", "creator", "subject")]

==> OAIHarvester_0.1-7.tar.gz: OAIHarvester/inst/doc/oaih.R <==
### R code from vignette source 'oaih.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: oaih.Rnw:193-195
###################################################
library("OAIHarvester")
baseurl <- "http://epub.wu.ac.at/cgi/oai2"


###################################################
### code chunk number 2: oaih.Rnw:199-202
###################################################
require("XML")
options(warnPartialMatchArgs = FALSE)
options(width = 80)


###################################################
### code chunk number 3: oaih.Rnw:207-209
###################################################
x <- oaih_identify(baseurl)
rbind(x, deparse.level = 0)


###################################################
### code chunk number 4: oaih.Rnw:215-216
###################################################
sapply(x$description, xmlName)


###################################################
### code chunk number 5: oaih.Rnw:220-221
###################################################
oaih_transform(x$description[[1L]])


###################################################
### code chunk number 6: oaih.Rnw:226-229
###################################################
oaih_list_metadata_formats(baseurl)
sets <- oaih_list_sets(baseurl)
rbind(head(sets, 3L), tail(sets, 3L))


###################################################
### code chunk number 7: oaih.Rnw:235-236
###################################################
spec <- unlist(sets[sets[, "setName"] == "Type = Thesis", "setSpec"])


###################################################
### code chunk number 8: oaih.Rnw:239-240
###################################################
x <- oaih_list_records(baseurl, set = spec)


###################################################
### code chunk number 9: oaih.Rnw:244-246
###################################################
dim(x)
colnames(x)


###################################################
### code chunk number 10: oaih.Rnw:251-254
###################################################
m <- x[, "metadata"]
m <- oaih_transform(m[sapply(m, length) > 0L])
dim(m)


###################################################
### code chunk number 11: oaih.Rnw:257-258
###################################################
colnames(m)


###################################################
### code chunk number 12: oaih.Rnw:310-311
###################################################
m[c(1L, 6L, 7L), "subject"]


###################################################
### code chunk number 13: oaih.Rnw:315-320
###################################################
sep <- "[[:space:]]*/[[:space:]]*"
keywords_by_thesis <-
    strsplit(unlist(lapply(m[, "subject"],  paste, collapse = " / ")),
             sep)
keywords <- unlist(keywords_by_thesis)


###################################################
### code chunk number 14: oaih.Rnw:324-326
###################################################
counts <- table(keywords)
table(counts)


###################################################
### code chunk number 15: oaih.Rnw:330-331
###################################################
sort(counts[counts >= 3L], decreasing = TRUE)


###################################################
### code chunk number 16: oaih.Rnw:335-336
###################################################
counts["R"]


###################################################
### code chunk number 17: oaih.Rnw:339-342
###################################################
lapply(m[sapply(keywords_by_thesis, function(kw) any(kw == "R")),
         c("title", "creator")],
       strwrap)


###################################################
### code chunk number 18: oaih.Rnw:347-349
###################################################
m[grep("^Feinerer", unlist(m[, "creator"])),
  c("title", "creator", "subject")]
